@@ -29,7 +29,8 @@
 static struct ol_object *all_objects = NULL;
 static unsigned number_of_objects = 0;
 static unsigned live_objects = 0;
-unsigned gc_threshold = 100; 
+unsigned gc_busy_threshold = 500; 
+unsigned gc_idle_threshold = 50;
 
 #if 0
 static struct ol_object *globals = NULL;
@@ -210,7 +211,8 @@ void gc_maybe(struct ol_object *root, int busy)
   sanity_check_object_list();
 #endif
 
-  if (number_of_objects > (gc_threshold + live_objects*(2+busy)))
+  if (busy && (number_of_objects > gc_busy_threshold) ||
+      !busy && (number_of_objects > gc_idle_threshold))
     { 
 
       verbose("Garbage collecting while %z...\n", busy ? "busy" : "idle");
