@@ -24,7 +24,8 @@
 #ifndef __GC_H_INCLUDED
 #define __GC_H_INCLUDED
 
-extern unsigned gc_threshold;
+extern unsigned gc_idle_threshold;
+extern unsigned gc_busy_threshold;
 
 void gc_register(struct ol_object *o);
 void gc_kill(struct ol_object *o);
