@@ -107,7 +107,7 @@ closes
 		
 		struct nonblocking_fd **fd_p;
 		struct nonblocking_fd *fd;
-		
+
 		for(fd_p = &b->files; (fd = *fd_p); ) {
 			if (fd->super.alive) {
 				if (fd->prepare) {
@@ -116,9 +116,7 @@ closes
 					kill_fd(fd);
 				}
 			}
-			
-			if (!fd->super.alive)
-			{
+			else {
 				if (fd->fd < 0)
 					/* Unlink the file object, but don't close any underlying file. */
 					;
@@ -232,23 +230,22 @@ closes
 					WRITE_FD(fd);
 				else {
 					verbose("io_iter(): POLLHUP on inactive fd!\n");
-					closekill_fd(fd, CLOSE_EOF);
+					close_fd(fd, CLOSE_EOF);
 				}
 				continue;
 			}
 			if (fds[i].revents & POLLPRI) {
-				closekill_fd(fd, CLOSE_PROTOCOL_FAILURE);
+				close_fd(fd, CLOSE_PROTOCOL_FAILURE);
+				continue;
+			}
+			if (fds[i].revents & (POLLNVAL | POLLERR)) {
+				close_fd(fd, CLOSE_POLL_FAILED);
 				continue;
 			}
-			if (fds[i].revents & (POLLNVAL | POLLERR))
-				closekill_fd(fd, CLOSE_POLL_FAILED);
 			if (fds[i].revents & POLLOUT)
 				if (fd->want_write && fd->write)
 					WRITE_FD(fd);
 			
-			if (!fd->super.alive)
-				continue;
-			
 			if (fds[i].revents & POLLIN) {
 				if (fd->want_read && fd->read)
 					READ_FD(fd);
@@ -270,7 +267,7 @@ closes
 		}
 	}
 	if (!nfds && !nco) {
-		verbose("io_iter(): no waiting fds and no callouts! exiting...\n");
+		verbose("No listening fds and no pending events, exiting...\n");
 		return 0;
 	}
 	return 1;
@@ -486,7 +483,7 @@ static void write_callback(struct nonblocking_fd *fd)
 	res = BUF_FLUSH(self->buffer, &w.super);
 	if (ST_CLOSEDP(res))
 	{
-		closekill_fd(fd, ST_FAILUREP(res) ? CLOSE_PROTOCOL_FAILURE : CLOSE_EOF);
+		close_fd(fd, ST_FAILUREP(res) ? CLOSE_PROTOCOL_FAILURE : CLOSE_EOF);
 	}
 }  
 
@@ -909,6 +906,12 @@ static int bind_unix_socket(struct address_info *c, int fd)
 	struct sockaddr_un un;
 
 	if (unix_address2sockaddr_un(c, sizeof(un), (struct sockaddr *) &un)) {
+		struct stat st;
+
+		if (stat(un.sun_path, &st) == 0 && !S_ISSOCK(st.st_mode)) {
+			werror("io.c: bind_unix_socket(): %z not a socket\n", un.sun_path);
+			return -1;
+		}
 		unlink(un.sun_path);
 		errno = 0;
 		if (bind(fd, (struct sockaddr *) &un, sizeof(struct sockaddr_un)) == -1) {
