@@ -109,8 +109,8 @@ static int do_flush(struct abstract_buffer *c, struct abstract_write *w)
 			}
 		}
 		else {
-			werror("pkt_buffer::do_flush(): Error flushing data\n");
-			return ST_FAIL | ST_CLOSE;
+			verbose("pkt_buffer::do_flush(): Error flushing data\n");
+			return ST_CLOSE;
 		}
 	}
 	return ST_OK | ST_GOON;
